@@ -37,20 +37,21 @@ void ThunderbirdSettings::importSettings()
     QTextStream stream(&file);
     while (!stream.atEnd()) {
         const QString line = stream.readLine();
-        if (line.startsWith(QLatin1String("user_pref"))) {
-            if (line.contains(QLatin1String("mail.smtpserver")) || line.contains(QLatin1String("mail.server."))
-                || line.contains(QLatin1String("mail.identity.")) || line.contains(QLatin1String("mail.account."))
-                || line.contains(QLatin1String("mail.accountmanager.")) || line.contains(QLatin1String("mailnews."))
-                || line.contains(QLatin1String("mail.compose.")) || line.contains(QLatin1String("mail.spellcheck"))
-                || line.contains(QLatin1String("mail.SpellCheckBeforeSend")) || line.contains(QLatin1String("spellchecker.dictionary"))
-                || line.contains(QLatin1String("ldap_")) || line.contains(QLatin1String("mail.biff.")) || line.contains(QLatin1String("mailnews.tags."))
-                || line.contains(QLatin1String("extensions.AutoResizeImage.")) || line.contains(QLatin1String("mail.phishing."))
-                || line.contains(QLatin1String("mail.display_glyph")) || line.contains(QLatin1String("extensions.sieve.account."))) {
+        if (line.startsWith(QLatin1StringView("user_pref"))) {
+            if (line.contains(QLatin1StringView("mail.smtpserver")) || line.contains(QLatin1StringView("mail.server."))
+                || line.contains(QLatin1StringView("mail.identity.")) || line.contains(QLatin1StringView("mail.account."))
+                || line.contains(QLatin1StringView("mail.accountmanager.")) || line.contains(QLatin1StringView("mailnews."))
+                || line.contains(QLatin1StringView("mail.compose.")) || line.contains(QLatin1StringView("mail.spellcheck"))
+                || line.contains(QLatin1StringView("mail.SpellCheckBeforeSend")) || line.contains(QLatin1StringView("spellchecker.dictionary"))
+                || line.contains(QLatin1StringView("ldap_")) || line.contains(QLatin1StringView("mail.biff."))
+                || line.contains(QLatin1StringView("mailnews.tags.")) || line.contains(QLatin1StringView("extensions.AutoResizeImage."))
+                || line.contains(QLatin1StringView("mail.phishing.")) || line.contains(QLatin1StringView("mail.display_glyph"))
+                || line.contains(QLatin1StringView("extensions.sieve.account."))) {
                 insertIntoMap(line);
             }
         } else {
-            if (!line.startsWith(QLatin1Char('#')) || line.isEmpty() || line.startsWith(QLatin1String("/*")) || line.startsWith(QLatin1String(" */"))
-                || line.startsWith(QLatin1String(" *"))) {
+            if (!line.startsWith(QLatin1Char('#')) || line.isEmpty() || line.startsWith(QLatin1StringView("/*")) || line.startsWith(QLatin1StringView(" */"))
+                || line.startsWith(QLatin1StringView(" *"))) {
                 qCDebug(THUNDERBIRDPLUGIN_LOG) << " unstored line :" << line;
             }
         }
@@ -143,7 +144,7 @@ void ThunderbirdSettings::readExtensionsSettings()
     const QString conversionFormatStr(QStringLiteral("extensions.AutoResizeImage.conversionFormat"));
     if (mHashConfig.contains(conversionFormatStr)) {
         QString conversionFormat = mHashConfig.value(conversionFormatStr).toString();
-        if (conversionFormat == QLatin1String("png")) {
+        if (conversionFormat == QLatin1StringView("png")) {
             conversionFormat = QStringLiteral("PNG");
         } else {
             conversionFormat = QStringLiteral("JPG");
@@ -191,10 +192,10 @@ void ThunderbirdSettings::readExtensionsSettings()
     const QString filteringRenamingPatternStr(QStringLiteral("extensions.AutoResizeImage.renamingPattern"));
     if (mHashConfig.contains(filteringRenamingPatternStr)) {
         QString filteringRenamingPattern = mHashConfig.value(filteringRenamingPatternStr).toString();
-        filteringRenamingPattern.replace(QLatin1String("%3Fn"), QLatin1String("%n"));
-        filteringRenamingPattern.replace(QLatin1String("%3Ft"), QLatin1String("%t"));
-        filteringRenamingPattern.replace(QLatin1String("%3Fd"), QLatin1String("%d"));
-        filteringRenamingPattern.replace(QLatin1String("%3Fe"), QLatin1String("%e"));
+        filteringRenamingPattern.replace(QLatin1StringView("%3Fn"), QLatin1StringView("%n"));
+        filteringRenamingPattern.replace(QLatin1StringView("%3Ft"), QLatin1StringView("%t"));
+        filteringRenamingPattern.replace(QLatin1StringView("%3Fd"), QLatin1StringView("%d"));
+        filteringRenamingPattern.replace(QLatin1StringView("%3Fe"), QLatin1StringView("%e"));
         addKmailConfig(QStringLiteral("AutoResizeImage"), QStringLiteral("rename-resized-images-pattern"), filteringRenamingPattern);
     }
 
@@ -293,9 +294,9 @@ void ThunderbirdSettings::readLdapSettings()
             ldap.ldapUrl = QUrl(mHashConfig.value(ldapUri).toString());
             ldap.port = ldap.ldapUrl.port();
 
-            if (ldap.ldapUrl.scheme() == QLatin1String("ldaps")) {
+            if (ldap.ldapUrl.scheme() == QLatin1StringView("ldaps")) {
                 ldap.useSSL = true;
-            } else if (ldap.ldapUrl.scheme() == QLatin1String("ldap")) {
+            } else if (ldap.ldapUrl.scheme() == QLatin1StringView("ldap")) {
                 ldap.useSSL = false;
             } else {
                 qCDebug(THUNDERBIRDPLUGIN_LOG) << " Security not implemented :" << ldap.ldapUrl.scheme();
@@ -591,7 +592,7 @@ void ThunderbirdSettings::readAccount()
             loginAtStartup = mHashConfig.value(loginAtStartupStr).toBool();
         }
         bool found = false;
-        if (type == QLatin1String("imap")) {
+        if (type == QLatin1StringView("imap")) {
             QMap<QString, QVariant> settings;
             settings.insert(QStringLiteral("ImapServer"), host);
             settings.insert(QStringLiteral("UserName"), userName);
@@ -660,7 +661,7 @@ void ThunderbirdSettings::readAccount()
             addCheckMailOnStartup(agentIdentifyName, loginAtStartup);
             // Not find a method to disable it in thunderbird
             addToManualCheck(agentIdentifyName, true);
-        } else if (type == QLatin1String("pop3")) {
+        } else if (type == QLatin1StringView("pop3")) {
             QMap<QString, QVariant> settings;
             settings.insert(QStringLiteral("Host"), host);
             settings.insert(QStringLiteral("Login"), userName);
@@ -725,10 +726,10 @@ void ThunderbirdSettings::readAccount()
             addCheckMailOnStartup(agentIdentifyName, loginAtStartup);
             // Not find a method to disable it in thunderbird
             addToManualCheck(agentIdentifyName, true);
-        } else if (type == QLatin1String("none")) {
+        } else if (type == QLatin1StringView("none")) {
             // FIXME look at if we can implement it
             qCDebug(THUNDERBIRDPLUGIN_LOG) << " account type none!";
-        } else if (type == QLatin1String("rss") || type == QLatin1String("nntp") || type == QLatin1String("movemail")) {
+        } else if (type == QLatin1StringView("rss") || type == QLatin1StringView("nntp") || type == QLatin1StringView("movemail")) {
             qCDebug(THUNDERBIRDPLUGIN_LOG) << QStringLiteral("%1 rss resource needs to be implemented").arg(type);
             continue;
         } else {
@@ -975,9 +976,9 @@ void ThunderbirdSettings::insertIntoMap(const QString &line)
         // Store as String
         mHashConfig.insert(key, valueStr);
     } else {
-        if (valueStr == QLatin1String("true")) {
+        if (valueStr == QLatin1StringView("true")) {
             mHashConfig.insert(key, true);
-        } else if (valueStr == QLatin1String("false")) {
+        } else if (valueStr == QLatin1StringView("false")) {
             mHashConfig.insert(key, false);
         } else {
             // Store as integer
@@ -985,11 +986,11 @@ void ThunderbirdSettings::insertIntoMap(const QString &line)
             mHashConfig.insert(key, value);
         }
     }
-    if (key.contains(QLatin1String("ldap_")) && key.endsWith(QLatin1String(".description"))) {
+    if (key.contains(QLatin1StringView("ldap_")) && key.endsWith(QLatin1StringView(".description"))) {
         QString ldapAccountName = key;
         mLdapAccountList.append(ldapAccountName.remove(QStringLiteral(".description")));
     }
-    if (key.contains(QLatin1String("mailnews.tags.")) && (key.endsWith(QLatin1String(".color")) || key.endsWith(QLatin1String(".tag")))) {
+    if (key.contains(QLatin1StringView("mailnews.tags.")) && (key.endsWith(QLatin1StringView(".color")) || key.endsWith(QLatin1StringView(".tag")))) {
         QString name = key;
         name.remove(QStringLiteral("mailnews.tags."));
         name.remove(QStringLiteral(".color"));
@@ -999,7 +1000,7 @@ void ThunderbirdSettings::insertIntoMap(const QString &line)
             tag = mHashTag.value(name);
             mHashTag.remove(name);
         }
-        if (key.endsWith(QLatin1String(".color"))) {
+        if (key.endsWith(QLatin1StringView(".color"))) {
             tag.color = QColor(mHashConfig.value(key).toString());
         } else {
             tag.name = mHashConfig.value(key).toString();
